package controller

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"github.com/sirupsen/logrus"
	"youngee_b_api/app/service"
	"youngee_b_api/app/util"
	"youngee_b_api/app/vo"
)

type FinanceController struct{}

// 充值管理——对公转账
func (t FinanceController) TransferToPublic(c *gin.Context) {
	param := &vo.RechargeTransferParam{}
	err := c.BindJSON(param)
	if err != nil {
		logrus.Errorf("Request bind err:%+v\n", err)
		returnError(c, 40000, "参数错误")
		return
	}
	rechargeId, err := service.RechargeService{}.TransferToPublic(param)
	if err != nil {
		logrus.Errorf("[TransferToPublic] call Show err:%+v\n", err)
		returnError(c, 40000, "error")
		return
	}
	resultMap := make(map[string]string)
	resultMap["rechargeId"] = *rechargeId
	returnSuccess(c, 20000, resultMap)
}

// 获取微信支付CodeUrl
func (t FinanceController) GetCodeUrl(c *gin.Context) {
	param := &vo.GetCodeUrlParam{}
	err := c.BindJSON(param)
	if err != nil {
		logrus.Errorf("Request bind err:%+v\n", err)
		returnError(c, 40000, "参数错误")
		return
	}
	tradeId := util.GetRandomString(32)
	fmt.Println("amount:", param.Amount)
	codeUrl, err := service.RechargeService{}.NativeApiServicePrepay(tradeId, param.Amount)
	if err != nil {
		logrus.Errorf("[GetCodeUrl] call Show err:%+v\n", err)
		returnError(c, 40000, "error")
		return
	}
	reCodeUrl := new(vo.ReCodeUrl)
	reCodeUrl.CodeUrl = codeUrl
	reCodeUrl.TradeId = tradeId

	returnSuccess(c, 20000, reCodeUrl)
}

// 根据交易id查询微信是否扫码付款
func (t FinanceController) QueryOrderByTradeId(c *gin.Context) {
	param := &vo.QueryOrderByTradeIdParam{}
	err := c.BindJSON(param)
	if err != nil {
		logrus.Errorf("Request bind err:%+v\n", err)
		returnError(c, 40000, "参数错误")
		return
	}
	tradeState, err := service.RechargeService{}.QueryOrderByTradeId(param.TradeId)
	if err != nil {
		logrus.Errorf("[QueryOrderByTradeId] call Show err:%+v\n", err)
		returnError(c, 40000, "error")
		return
	}
	returnSuccess(c, 20000, tradeState)
}
