package dao

import (
	"github.com/sirupsen/logrus"
	"youngee_b_api/app/entity"
)

type ProductPhotoDAO struct{}

func (d ProductPhotoDAO) GetMainPhotoByProductID(productId int64) (string, error) {
	var productPhoto entity.ProductPhoto
	err := Db.Where("product_id = ? AND symbol = ?", productId, 1).First(&productPhoto).Error
	if err != nil {
		return "", err
	}
	return productPhoto.PhotoUrl, nil
}

func (d ProductPhotoDAO) CreateProductPhoto(productPhotos []entity.ProductPhoto) error {
	err := Db.Create(&productPhotos).Error
	if err != nil {
		return err
	}
	return nil
}

func (d ProductPhotoDAO) GetProductPhotoByProductID(productID int64) ([]entity.ProductPhoto, error) {
	var productPhotos []entity.ProductPhoto
	err := Db.Where("product_id = ?", productID).Find(&productPhotos).Error
	if err != nil {
		return nil, err
	}
	return productPhotos, nil
}

func (d ProductPhotoDAO) GetProductPhotosBySelectionId(selectionId string) ([]*entity.ProductPhoto, error) {
	productId := 0
	err := Db.Model(entity.SelectionInfo{}).Select("product_id").Where("selection_id = ?", selectionId).Find(&productId).Error
	if err != nil {
		logrus.Errorf("[GetProductInfo] error query mysql, err:%+v", err)
		return nil, err
	}
	var productPhotos []*entity.ProductPhoto
	err = Db.Model(entity.ProductPhoto{}).Where("product_id = ?", productId).Find(&productPhotos).Error
	if err != nil {
		logrus.Errorf("[GetProductInfo] error query mysql, err:%+v", err)
		return nil, err
	}
	return productPhotos, nil
}

func (d ProductPhotoDAO) GetProductPhotosByProjectId(projectId string) ([]*entity.ProductPhoto, error) {
	productId := 0
	err := Db.Model(entity.Project{}).Select("product_id").Where("project_id = ?", projectId).Find(&productId).Error
	if err != nil {
		logrus.Errorf("[GetProductInfo] error query mysql, err:%+v", err)
		return nil, err
	}
	var productPhotos []*entity.ProductPhoto
	err = Db.Model(entity.ProductPhoto{}).Where("product_id = ?", productId).Find(&productPhotos).Error
	if err != nil {
		logrus.Errorf("[GetProductInfo] error query mysql, err:%+v", err)
		return nil, err
	}
	return productPhotos, nil
}
